==> 3.5.12-core.tar: kdenetwork/kopete/protocols/gadu/gadupubdir.h <==
//
// Copyright (C) 2003	 Grzegorz Jaskiewicz <gj at pointblue.com.pl>
//
// gadupubdir.h
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
// 02110-1301, USA.
//

#ifndef GADUPUBDIR_H
#define GADUPUBDIR_H

#include "gadusearch.h"
#include "gadusession.h"

#include <kdebug.h>
#include <kdialogbase.h>

class GaduAccount;
class GaduProtocol;
class GaduContact;
class GaduAccount;
class GaduPublicDirectory;
class TQListViewItem;
class GaduContact;

class GaduPublicDir : public KDialogBase
{
Q_OBJECT

public:
	GaduPublicDir( GaduAccount* , TQWidget *parent = 0, const char* name = "GaduPublicDir" );
	GaduPublicDir( GaduAccount* , int searchFor, TQWidget* parent = 0, const char* name = "GaduPublicDir" );
	TQPixmap iconForStatus( uint status );

private slots:
	void slotSearch();
	void slotNewSearch();
	void slotSearchResult( const SearchResult& result, unsigned int seq );
	void slotAddContact();
	void inputChanged( const TQString& );
	void inputChanged( bool );
	void slotListSelected();


private:
	void getData();
	bool validateData();
	void createWidget();
	void initConnections();

	GaduProtocol*		p;
	GaduAccount*		mAccount;
	GaduContact*		mContact;
	GaduPublicDirectory*	mMainWidget;

// form data
	QString	fName;
	QString	fSurname;
	QString	fNick;
	QString	fCity;
	int		fUin;
	int		fGender;
	bool		fOnlyOnline;
	int		fAgeFrom;
	int		fAgeTo;
};
#endif

==> 3.5.13-core.tar: kdenetwork/kopete/protocols/gadu/gadupubdir.h <==
//
// Copyright (C) 2003	 Grzegorz Jaskiewicz <gj at pointblue.com.pl>
//
// gadupubdir.h
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
// 02110-1301, USA.
//

#ifndef GADUPUBDIR_H
#define GADUPUBDIR_H

#include "gadusearch.h"
#include "gadusession.h"

#include <kdebug.h>
#include <kdialogbase.h>

class GaduAccount;
class GaduProtocol;
class GaduContact;
class GaduAccount;
class GaduPublicDirectory;
class TQListViewItem;
class GaduContact;

class GaduPublicDir : public KDialogBase
{
Q_OBJECT
  TQ_OBJECT

public:
	GaduPublicDir( GaduAccount* , TQWidget *parent = 0, const char* name = "GaduPublicDir" );
	GaduPublicDir( GaduAccount* , int searchFor, TQWidget* parent = 0, const char* name = "GaduPublicDir" );
	TQPixmap iconFortqStatus( uint status );

private slots:
	void slotSearch();
	void slotNewSearch();
	void slotSearchResult( const SearchResult& result, unsigned int seq );
	void slotAddContact();
	void inputChanged( const TQString& );
	void inputChanged( bool );
	void slotListSelected();


private:
	void getData();
	bool validateData();
	void createWidget();
	void initConnections();

	GaduProtocol*		p;
	GaduAccount*		mAccount;
	GaduContact*		mContact;
	GaduPublicDirectory*	mMainWidget;

// form data
	TQString	fName;
	TQString	fSurname;
	TQString	fNick;
	TQString	fCity;
	int		fUin;
	int		fGender;
	bool		fOnlyOnline;
	int		fAgeFrom;
	int		fAgeTo;
};
#endif
